User Guide
================

.. toctree::
   :maxdepth: 1

   installation.rst
   data_structures.rst
   initialization.rst
   indexing.rst
   multi-indexing.rst
   query.rst
   call_method.rst
   pandas_methods.rst
   numpy_functions.rst
   operators_and_compatibility.rst
   compatibility_with_pandas.rst
   grouping.rst
